@@ -206,7 +206,7 @@ var DefaultController =
       case "cmd_getMsgsForAuthAccounts":
 			case "cmd_getNextNMessages":
 			case "cmd_find":
-			case "cmd_findAgain":
+      case "cmd_findNext":
 			case "cmd_findPrev":
       case "button_search":
       case "cmd_search":
@@ -238,7 +238,7 @@ var DefaultController =
       case "cmd_downloadFlagged":
       case "cmd_downloadSelected":
       case "cmd_synchronizeOffline":
-        return(CheckOnline());
+        return !Services.io.offline;
 
       case "cmd_watchThread":
       case "cmd_killThread":
@@ -410,7 +410,7 @@ var DefaultController =
       case "cmd_markReadByDate":
         return IsFolderSelected();
       case "cmd_find":
-      case "cmd_findAgain":
+      case "cmd_findNext":
       case "cmd_findPrev":
         return IsMessageDisplayedInMessagePane();
         break;
@@ -464,11 +464,12 @@ var DefaultController =
       case "cmd_close":
         return true;
       case "cmd_downloadFlagged":
-        return(CheckOnline());
+        return !Services.io.offline;
       case "cmd_downloadSelected":
-        return (IsFolderSelected() && CheckOnline() && GetNumSelectedMessages() > 0);
+        return IsFolderSelected() && !Services.io.offline &&
+               GetNumSelectedMessages() > 0;
       case "cmd_synchronizeOffline":
-        return CheckOnline();
+        return !Services.io.offline;
       case "cmd_settingsOffline":
         return IsAccountOfflineEnabled();
       default:
@@ -652,7 +653,7 @@ var DefaultController =
 			case "cmd_find":
 				MsgFind();
 				return;
-			case "cmd_findAgain":
+      case "cmd_findNext":
 				MsgFindAgain(false);
 				return;
 			case "cmd_findPrev":
