@@ -189,10 +189,6 @@ pref("browser.urlbar.restrict.typed", "~");
 pref("browser.urlbar.match.title", "#");
 pref("browser.urlbar.match.url", "@");
 
-// Whether or not microsummary and generator updates are enabled.
-pref("browser.microsummary.enabled", true);
-pref("browser.microsummary.updateGenerators", true);
-
 pref("browser.history.grouping", "day");
 pref("browser.sessionhistory.max_entries", 50);
 
@@ -288,6 +284,11 @@ pref("browser.tabs.tabClipWidth", 140);
 // 3  at the end of the tabstrip
 pref("browser.tabs.closeButtons", 3);
 
+// Mouse wheel action when over the tab bar:
+// false  The mouse wheel scrolls the whole tab bar like Firefox (default).
+// true   The mouse wheel advances the selected tab.
+pref("browser.tabs.mouseScrollAdvancesTab", false);
+
 // lets new tab/window load something different than first window
 // -1 - use navigator startup preference
 //  0 - loads blank page
@@ -332,6 +333,9 @@ pref("browser.zoom.siteSpecific", true);
 // once they come to the foreground (i.e. get activated).
 pref("browser.zoom.updateBackgroundTabs", true);
 
+// Zoom levels for View > Zoom and Ctrl +/- keyboard shortcuts
+pref("toolkit.zoomManager.zoomValues", "0.5,0.67,0.8,0.9,1,1.1,1.2,1.33,1.5,1.7,2,2.4");
+
 pref("javascript.options.showInConsole",    true);
 
 pref("offline.startup_state",            0);
@@ -361,13 +365,13 @@ pref("accessibility.blockautorefresh", false);
 // Use the findbar for type ahead find, instead of the XPFE implementation
 pref("accessibility.typeaheadfind.usefindbar", true);
 pref("accessibility.typeaheadfind.flashBar", 0);
-//@line 367 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 371 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 
-//@line 371 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 375 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 pref("browser.preferences.instantApply", true);
-//@line 376 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 380 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 378 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 382 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 
 pref("browser.download.show_plugins_in_list", true);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -509,13 +513,14 @@ pref("app.update.cert.maxErrors", 5);
 // |app.update.url.override| preference for update checking.
 pref("app.update.certs.1.issuerName", "OU=Equifax Secure Certificate Authority,O=Equifax,C=US");
 pref("app.update.certs.1.commonName", "aus2-community.mozilla.org");
+pref("app.update.certs.2.issuerName", "CN=GeoTrust SSL CA,O=\"GeoTrust, Inc.\",C=US");
+pref("app.update.certs.2.commonName", "aus2-community.mozilla.org");
+pref("app.update.certs.3.issuerName", "CN=Thawte SSL CA,O=\"Thawte, Inc.\",C=US");
+pref("app.update.certs.3.commonName", "aus2-community.mozilla.org");
 
 // Interval: Time between checks for a new version (in seconds)
 //           default=1 day
 pref("app.update.interval", 86400);
-// Interval: Time before prompting the user again to restart to install the
-//           latest download (in seconds) default=1 day
-pref("app.update.nagTimer.restart", 86400);
 // The minimum delay in seconds for the timer to fire.
 // default=2 minutes
 pref("app.update.timerMinimumDelay", 120);
@@ -544,8 +549,12 @@ pref("extensions.logging.enabled", false);
 // Blocklist preferences
 pref("extensions.blocklist.enabled", true);
 pref("extensions.blocklist.interval", 86400);
+// Controls what level the blocklist switches from warning about items to forcibly
+// blocking them.
+pref("extensions.blocklist.level", 2);
 pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/3/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/%PING_COUNT%/%TOTAL_PING_COUNT%/%DAYS_SINCE_LAST_PING%/");
 pref("extensions.blocklist.detailsURL", "https://www.mozilla.com/%LOCALE%/blocklist/");
+pref("extensions.blocklist.itemURL", "https://addons.mozilla.org/%LOCALE%/%APP%/blocked/%blockID%");
 
 // Update preferences for installed Extensions and Themes.
 // Symmetric (can be overridden by individual extensions),
@@ -571,6 +580,7 @@ pref("extensions.webservice.discoverURL", "https://services.addons.mozilla.org/%
 
 // getMoreThemes is used by our UI under our switch theme menu
 pref("extensions.getMoreThemesURL", "chrome://branding/locale/brand.properties");
+pref("extensions.getPersonasURL", "chrome://branding/locale/brand.properties");
 pref("extensions.dss.enabled", false);          // Dynamic Skin Switching
 pref("extensions.dss.switchPending", false);    // Non-dynamic switch pending after next
                                                 // restart.
@@ -592,7 +602,7 @@ pref("custtoolbar.personal_toolbar_folder", "");
 // Use a popup window for the customize toolbar UI
 pref("toolbar.customization.usesheet", false);
 
-//@line 612 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 620 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 
 pref("sidebar.customize.all_panels.url", "http://sidebar-rdf.netscape.com/%LOCALE%/sidebar-rdf/%SIDEBAR_VERSION%/all-panels.rdf");
 pref("sidebar.customize.directory.url", "http://dmoz.org/Netscape/Sidebar/");
@@ -662,9 +672,9 @@ pref("dom.event.contextmenu.enabled",  true);
 
 // The default for this pref reflects whether the build is capable of IPC.
 // (Turning it on in a no-IPC build will have no effect.)
-//@line 701 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
-pref("dom.ipc.plugins.enabled", false);
-//@line 703 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 707 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
+pref("dom.ipc.plugins.enabled", true);
+//@line 709 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 
 // plugin finder service url
 pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.php?mimetype=%PLUGIN_MIMETYPE%&appID=%APP_ID%&appVersion=%APP_VERSION%&clientOS=%CLIENT_OS%&chromeLocale=%CHROME_LOCALE%");
@@ -674,16 +684,24 @@ pref("plugins.hide_infobar_for_outdated_plugin", false);
 pref("plugins.hide_infobar_for_carbon_failure_plugin", false);
 pref("plugins.hide_infobar_for_missing_plugin", false);
 
-//@line 713 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 721 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
+
+//@line 723 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 // Restore the spinner that was removed in bug 481359
 pref("ui.use_activity_cursor", true);
-//@line 716 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 726 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 
-//@line 731 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 731 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 
-//@line 734 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 734 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 // For the download dialog
 pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", false);
+
+// Mouse wheel action when over the tab bar:
+// false  The mouse wheel scrolls the whole tab bar like Firefox.
+// true   The mouse wheel advances the selected tab.
+pref("browser.tabs.mouseScrollAdvancesTab", true);
+
 pref("browser.urlbar.clickSelectsAll", false);
 
 // 0 goes back
@@ -694,7 +712,7 @@ pref("browser.backspace_action", 2);
 pref("general.autoScroll", false);
 
 pref("layout.word_select.stop_at_punctuation", false);
-//@line 748 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 754 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 
 // The breakpad report server to link to in about:crashes
 pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
@@ -708,7 +726,7 @@ pref("browser.geolocation.warning.infoURL", "http://www.seamonkey-project.org/do
 pref("browser.rights.version", 1);
 pref("browser.rights.1.shown", false);
 
-//@line 768 "/usr/obj/i386/seamonkey-2.2/comm-release/suite/browser/browser-prefs.js"
+//@line 774 "/usr/ports/pobj/seamonkey-2.6.1/comm-release/suite/browser/browser-prefs.js"
 
 // The sync engines to use.
 pref("services.sync.registerEngines", "Bookmarks,Form,History,Password,Prefs,Tab");
