@@ -1,4 +1,4 @@
-//@line 43 "/usr/obj/i386/seamonkey-2.2/comm-release/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 43 "/usr/obj/ports/seamonkey-2.6.1/comm-release/mozilla/toolkit/content/contentAreaUtils.js"
 
 var ContentAreaUtils = {
   get ioService() {
@@ -300,7 +300,10 @@ function internalSave(aURL, aDocument, aDefaultFileName, aContentDisposition,
       file: file
     };
 
-    if (!getTargetFile(fpParams, aSkipPrompt))
+    // Find a URI to use for determining last-downloaded-to directory
+    let relatedURI = aReferrer || sourceURI;
+
+    if (!getTargetFile(fpParams, aSkipPrompt, relatedURI))
       // If the method returned false this is because the user cancelled from
       // the save file picker dialog.
       return;
@@ -510,10 +513,14 @@ function initFileInfo(aFI, aURL, aURLCharset, aDocument,
  *        If false, don't save the file automatically to the user's
  *        default download directory, even if the associated preference
  *        is set, but ask for the target explicitly.
+ * @param aRelatedURI
+ *        An nsIURI associated with the download. The last used
+ *        directory of the picker is retrieved from/stored in the 
+ *        Content Pref Service using this URI.
  * @return true if the user confirmed a filename in the picker or the picker
  *         was not displayed; false if they dismissed the picker.
  */
-function getTargetFile(aFpP, /* optional */ aSkipPrompt)
+function getTargetFile(aFpP, /* optional */ aSkipPrompt, /* optional */ aRelatedURI)
 {
   if (typeof gDownloadLastDir != "object")
     Components.utils.import("resource://gre/modules/DownloadLastDir.jsm");
@@ -546,7 +553,7 @@ function getTargetFile(aFpP, /* optional */ aSkipPrompt)
     // file picker if it is still valid. Otherwise, keep the default of the
     // user's default downloads directory. If it doesn't exist, it will be
     // changed to the user's desktop later.
-    var lastDir = gDownloadLastDir.file;
+    var lastDir = gDownloadLastDir.getFile(aRelatedURI);
     if (lastDir.exists()) {
       dir = lastDir;
       dirExists = true;
@@ -590,7 +597,7 @@ function getTargetFile(aFpP, /* optional */ aSkipPrompt)
 
   // Do not store the last save directory as a pref inside the private browsing mode
   var directory = fp.file.parent.QueryInterface(nsILocalFile);
-  gDownloadLastDir.file = directory;
+  gDownloadLastDir.setFile(aRelatedURI, directory);
 
   fp.file.leafName = validateFileName(fp.file.leafName);
   
@@ -936,7 +943,7 @@ function getNormalizedLeafName(aFile, aDefaultExtension)
   if (!aDefaultExtension)
     return aFile;
 
-//@line 984 "/usr/obj/i386/seamonkey-2.2/comm-release/mozilla/toolkit/content/contentAreaUtils.js"
+//@line 991 "/usr/obj/ports/seamonkey-2.6.1/comm-release/mozilla/toolkit/content/contentAreaUtils.js"
 
   // Remove leading dots
   aFile = aFile.replace(/^\.+/, "");
