@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/i386/seamonkey-2.2/comm-release/mozilla/toolkit/components/viewsource/content/viewSource.js"
+//@line 40 "/usr/obj/ports/seamonkey-2.6.1/comm-release/mozilla/toolkit/components/viewsource/content/viewSource.js"
 
 const Cc = Components.classes;
 const Ci = Components.interfaces;
@@ -88,7 +88,7 @@ function viewSource(url)
 
   gBrowser.addEventListener("pagehide", onUnloadContent, true);
   gBrowser.addEventListener("pageshow", onLoadContent, true);
-  gBrowser.addEventListener("command", onCommandContent, false);
+  gBrowser.addEventListener("click", onClickContent, false);
 
   var loadFromURL = true;
 
@@ -239,11 +239,11 @@ function onUnloadContent()
 }
 
 /**
- * Handle command events bubbling up from error page content
+ * Handle click events bubbling up from error page content
  */
-function onCommandContent(event) {
+function onClickContent(event) {
   // Don't trust synthetic events
-  if (!event.isTrusted)
+  if (!event.isTrusted || event.target.localName != "button")
     return;
 
   var target = event.originalTarget;
@@ -285,9 +285,7 @@ function onCommandContent(event) {
         }
       }
     } else if (target == errorDoc.getElementById('ignoreWarningButton')) {
-      // Allow users to override and continue through to the site,
-      // but add a notify bar as a reminder, so that they don't lose
-      // track after, e.g., tab switching.
+      // Allow users to override and continue through to the site
       gBrowser.loadURIWithFlags(content.location.href,
                                 Ci.nsIWebNavigation.LOAD_FLAGS_BYPASS_CLASSIFIER,
                                 null, null, null);
