@@ -1,4 +1,6 @@
-//@line 37 "/usr/obj/ports/seamonkey-2.2/comm-release/mozilla/toolkit/mozapps/extensions/content/eula.js"
+//@line 37 "/usr/obj/ports/seamonkey-2.6.1/comm-release/mozilla/toolkit/mozapps/extensions/content/eula.js"
+
+"use strict";
 
 function Startup() {
   var bundle = document.getElementById("extensionsStrings");
